/*

  4x4 Matrix 16 Keys Button Keypad Module

  Parts required:
  - Arduino Board
  - 4x4 Matrix 16 Keys Button Keypad Module

  Libray:
  - Adafruit Keypad   Version 1.0.5 or newer

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 29 Mar 2020
  Version : v1.0

*/

#include "Adafruit_Keypad.h"                                                                      // include Adafruit_Keypad.h library

const byte ROWS = 4;                                                                              // set variable ROWS to 4 keys
const byte COLS = 4;                                                                              // set variable COLS to 4 keys

char keys[ROWS][COLS] = {                                                                         // define numbers for all keys
  {'1', '2', '3', '4'},
  {'5', '6', '7', '8'},
  {'9', '0', 'A', 'B'},
  {'C', 'D', 'E', 'F'}
};
byte rowPins[ROWS] = {5, 4, 3, 2};                                                                // set digitalport connection for ROWS
byte colPins[COLS] = {8, 9, 10, 11};                                                              // set digitalport connection for COLS

Adafruit_Keypad customKeypad = Adafruit_Keypad( makeKeymap(keys), rowPins, colPins, ROWS, COLS);  // create object and add all information

void setup() {
  Serial.begin(9600);                                                                             // start Serial Monitor communication
  customKeypad.begin();                                                                           // start the Adafruit Keypad object

}

void loop() {

  customKeypad.tick();                                                                            

  while (customKeypad.available()) {                                                              // check that the keyboard is read for communication
    keypadEvent e = customKeypad.read();                                                          // read for key press 
    Serial.print((char)e.bit.KEY);                                                                // print the number of key pressed
    if (e.bit.EVENT == KEY_JUST_PRESSED) Serial.println(" pressed");                              // print pressed when key is active
    else if (e.bit.EVENT == KEY_JUST_RELEASED) Serial.println(" released");                       // print released when key is inactive
  }

  delay(10);                                                                                      // wait 10ms
}
